#!/bin/bash 
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#-------------------------------------------------------------------------------
# Unit tests for org.glite.data.srm-util-cpp
# Authors: Zsolt Molnar <zsolt.molnar@cern.ch>
# Version info: $Id: stub_common.sh,v 1.1 2009/08/03 14:15:01 molnarzs Exp $
# Release: $Name:  $
#-------------------------------------------------------------------------------

export TESTS_CGSI_TRACE="CGSI_TRACE=1"
#export TESTS_CGSI_TRACE="--unset=CGSI_TRACE"

# check if the WORKSPACE environment variable is defined
if [ -z "${WORKSPACE}" ]; then
    echo "The WORKSPACE environment variable is not set."
    exit 1
fi

test_utils_module="org.glite.data.test-utils"
test_utils_dir="${WORKSPACE}/${test_utils_module}"

# source the test-common script
test_common_script="${test_utils_dir}/test-common.sh"
if [ ! -e ${test_common_script} ]; then
    echo "Checkout or update the ${test_utils_module} module."
    exit 1
fi
. ${test_common_script}

# source the test-proxy-utils script
test_proxy_utils_script="${test_utils_dir}/test-proxy-utils.sh"
if [ ! -e ${test_proxy_utils_script} ]; then
    echo "Checkout or update the ${test_utils_module} module."
    exit 1
fi
. ${test_proxy_utils_script}

#-------------------------------------------------------------------------------

# source the stub-srm-servers script
. ${script_dir}/stub-srm-servers.sh

MODULE_NAME="glite-data-srm-util-cpp"
MODULE_DIR="${WORKSPACE}/org.glite.data.srm-util-cpp"
MODULE_TEST_DIR="${GLITE_LOCATION}/share/test/${MODULE_NAME}"

SRM_UTIL_CPP_NAME="glite-data-srm-util-cpp"
SRM_UTIL_CPP_DIR="${WORKSPACE}/org.glite.data.srm-util-cpp"
SRM_UTIL_CPP_LOCATION="${GLITE_LOCATION}/share/test/${SRM_UTIL_CPP_NAME}"

addpath LD_LIBRARY_PATH ${SRM_UTIL_CPP_LOCATION}/lib
addpath LD_LIBRARY_PATH $(get_glite_path org.gridsite.core)/lib

# init_unit_test
function init_unit_test(){
    
    # add libraries paths
    add_gsoap_paths
    add_globus_paths
    add_log4cpp_paths
    add_glite_paths
    

    # create test directories
    mkdir -p ${MODULE_TEST_DIR}/{etc,bin,var/{log,tmp}}

    # copy configuration files
    cp -v ${MODULE_DIR}/config/glite-data-srm-util-cpp.patterns.xml ${MODULE_TEST_DIR}/etc

    # create certificates
    create_fake_certificates || return 1

    # initialize proxy
    grid_proxy_init || return 1
}

# test_srm_util_stub_sd_install
test_srm_util_stub_sd_install__DEPENDS="init_unit_test"
function test_srm_util_stub_sd_install(){
    srm_stub_servers_stub_sd_install
    return ${?}
}

# test_srm_util_stub_server_1_1_install
test_srm_util_stub_server_1_1_install__DEPENDS="init_unit_test"
function test_srm_util_stub_server_1_1_install(){
    srm_stub_servers_stub_server_1_1_install
    return ${?}
}

# test_srm_util_stub_server_2_2_install
test_srm_util_stub_server_2_2_install__DEPENDS="init_unit_test"
function test_srm_util_stub_server_2_2_install(){
    srm_stub_servers_stub_server_2_2_install
    return ${?}
}

# test_srm_util_install
test_srm_util_install__DEPENDS="init_unit_test"
function test_srm_util_install(){
    cat > ${MODULE_TEST_DIR}/config/glite-srm-util-test.config.xml << EOD
<service name="glite-srm-util-test">
<components>
<component name="glite-srm-util-test">
 <config-template>
  <description>Unit Test for SRM Util CPP</description>
   <!-- Statically allocated-->
 </config-template>
</component>
</components>
</service>
EOD
    (cd ${GLITE_LOCATION}/bin && ${GLITE_LOCATION}/bin/glite_data_config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-test.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-test.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-test.log-properties \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-test.log \
        -O log.Priority=DEBUG) || return ${?}
}

# start_stub_servers
start_stub_servers__DEPENDS="init_unit_test test_srm_util_stub_server_1_1_install test_srm_util_stub_server_2_2_install"
function start_stub_servers(){
    srm_stub_servers_start_stub_servers
    return ${?}
}

# stop_stub_servers
function stop_stub_servers(){
    srm_stub_servers_stop_stub_servers
    return ${?}
}
